@@ -1,6 +1,6 @@
 /*============================================================================
-  WCSLIB 7.3 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2020, Mark Calabretta
+  WCSLIB 7.4 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2021, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -17,11 +17,9 @@
   You should have received a copy of the GNU Lesser General Public License
   along with WCSLIB.  If not, see http://www.gnu.org/licenses.
 
-  Direct correspondence concerning WCSLIB to mark@calabretta.id.au
-
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: dis.c,v 7.3.1.2 2020/08/17 11:19:09 mcalabre Exp mcalabre $
+  $Id: dis.c,v 7.4 2021/01/31 02:24:51 mcalabre Exp $
 *===========================================================================*/
 
 #include <math.h>
@@ -1095,7 +1093,7 @@ int disp2x(
         // Distortion function computes a correction to be applied.
         discrd[j] = rawcrd[j] + dtmp;
       } else {
-        // Distortion function computes corrected coordinates.
+        // Distortion function computes corrected coordinates directly.
         discrd[j] = dtmp;
       }
 
@@ -1184,7 +1182,7 @@ int disx2p(
         // Inverse distortion function computes a correction to be applied.
         rawcrd[j] = discrd[j] + rtmp;
       } else {
-        // Inverse distortion function computes corrected coordinates.
+        // Inverse distortion function computes corrected coordinates directly.
         rawcrd[j] = rtmp;
       }
     }
@@ -1914,7 +1912,7 @@ int tpdset(int j, struct disprm *dis)
   dis->disx2p[j] = distpd[1];
 
 
-// These iparm indices are specific to TPD.
+// These iparm indices are specific to TPD (matching definitions in wcshdr.c).
 #define I_TPDNCO  3	// No. of TPD coefficients, forward...
 #define I_TPDINV  4	// ...and inverse.
 #define I_TPDAUX  5	// True if auxiliary variables are used.
@@ -2225,7 +2223,8 @@ int tpvset(int j, struct disprm *dis)
   // TPV "projection".
   sprintf(id, "TPV on axis %d", j+1);
 
-  // TPV computes corrected coordinates.
+  // TPV is a sequent distortion, applied to intermediate world coordinates
+  // (normally used with CDi_ja).  It computes corrected coordinates directly.
   dis->docorr[j] = 0;
 
   if (dis->Nhat[j] != 2) {
@@ -2380,7 +2379,7 @@ int sipset(int j, struct disprm *dis)
   sprintf(id, "SIP on axis %d", j+1);
 
 
-  // SIP computes an additive correction.
+  // SIP is a prior distortion that computes an additive correction.
   dis->docorr[j] = 1;
 
   if (dis->Nhat[j] != 2) {
@@ -2551,7 +2550,8 @@ int dssset(int j, struct disprm *dis)
   sprintf(id, "DSS on axis %d", j+1);
 
 
-  // DSS computes corrected coordinates.
+  // DSS is translated into a sequent distortion, applied to intermediate
+  // pixel coordinates.  It computes corrected coordinates directly.
   dis->docorr[j] = 0;
 
   if (dis->Nhat[j] != 2) {
@@ -2773,7 +2773,8 @@ int watset(int j, struct disprm *dis)
   sprintf(id, "WAT (%s) on axis %d", dis->dtype[0]+4, j+1);
 
 
-  // WAT computes an additive correction.
+  // WAT is a sequent distortion, applied to intermediate world coordinates
+  // (normally used with CDi_ja).  It computes an additive correction.
   dis->docorr[j] = 1;
 
   if (dis->Nhat[j] != 2) {
