@@ -1,6 +1,6 @@
 /*============================================================================
-  WCSLIB 7.3 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2020, Mark Calabretta
+  WCSLIB 7.4 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2021, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -17,11 +17,9 @@
   You should have received a copy of the GNU Lesser General Public License
   along with WCSLIB.  If not, see http://www.gnu.org/licenses.
 
-  Direct correspondence concerning WCSLIB to mark@calabretta.id.au
-
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: lin.c,v 7.3.1.2 2020/08/17 11:19:09 mcalabre Exp mcalabre $
+  $Id: lin.c,v 7.4 2021/01/31 02:24:51 mcalabre Exp $
 *===========================================================================*/
 
 #include <stdio.h>
@@ -661,11 +659,13 @@ int linset(struct linprm *lin)
     pc     = lin->pc;
     piximg = lin->piximg;
     for (i = 0; i < naxis; i++) {
-      for (j = 0; j < naxis; j++) {
-        if (lin->disseq == 0x0) {
-          // No sequent distortions, incorporate cdelt into piximg.
+      if (lin->disseq == 0x0) {
+        // No sequent distortions.  Incorporate cdelt into piximg.
+        for (j = 0; j < naxis; j++) {
           *(piximg++) = lin->cdelt[i] * (*(pc++));
-        } else {
+        }
+      } else {
+        for (j = 0; j < naxis; j++) {
           *(piximg++) = *(pc++);
         }
       }
@@ -818,7 +818,7 @@ int linp2x(
           return wcserr_set(LIN_ERRMSG(lin_diserr[status]));
         }
 
-        // With sequent distortions, cdelt is not incorporated into piximg.
+        // With sequent distortions, cdelt is not incorporated into piximg...
         for (i = 0; i < n; i++) {
           img[i] = lin->cdelt[i] * tmp[i];
         }
@@ -911,7 +911,7 @@ int linx2p(
 
     for (k = 0; k < ncoord; k++) {
       if (lin->disseq) {
-        // With sequent distortions, cdelt is not incorporated into imgpix.
+        // With sequent distortions, cdelt is not incorporated into imgpix...
         for (i = 0; i < n; i++) {
           tmp[i] = img[i] / lin->cdelt[i];
         }
