@@ -1,6 +1,6 @@
 /*============================================================================
-  WCSLIB 7.3 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2020, Mark Calabretta
+  WCSLIB 7.4 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2021, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -17,14 +17,12 @@
   You should have received a copy of the GNU Lesser General Public License
   along with WCSLIB.  If not, see http://www.gnu.org/licenses.
 
-  Direct correspondence concerning WCSLIB to mark@calabretta.id.au
-
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: sph.h,v 7.3.1.2 2020/08/17 11:19:09 mcalabre Exp mcalabre $
+  $Id: sph.h,v 7.4 2021/01/31 02:24:51 mcalabre Exp $
 *=============================================================================
 *
-* WCSLIB 7.3 - C routines that implement the FITS World Coordinate System
+* WCSLIB 7.4 - C routines that implement the FITS World Coordinate System
 * (WCS) standard.  Refer to the README file provided with WCSLIB for an
 * overview of the library.
 *
@@ -143,41 +141,41 @@
 *                         0: Success.
 *
 * Notes:
-*   sphdpa() uses sphs2x() to rotate coordinates so that the reference point
-*   is at the north pole of the new system with the north pole of the old
-*   system at zero longitude in the new.  The Euler angles required by
-*   sphs2x() for this rotation are
+*   1. sphdpa() uses sphs2x() to rotate coordinates so that the reference
+*      point is at the north pole of the new system with the north pole of the
+*      old system at zero longitude in the new.  The Euler angles required by
+*      sphs2x() for this rotation are
 *
-=     eul[0] = lng0;
-=     eul[1] = 90.0 - lat0;
-=     eul[2] =  0.0;
+=        eul[0] = lng0;
+=        eul[1] = 90.0 - lat0;
+=        eul[2] =  0.0;
 *
-*   The angular distance and generalized position angle are readily obtained
-*   from the longitude and latitude of the field point in the new system.
-*   This applies even if the reference point is at one of the poles, in which
-*   case the "position angle" returned is as would be computed for a reference
-*   point at (lng0,+90-epsilon) or (lng0,-90+epsilon), in the limit as epsilon
-*   goes to zero.
+*      The angular distance and generalized position angle are readily
+*      obtained from the longitude and latitude of the field point in the new
+*      system.  This applies even if the reference point is at one of the
+*      poles, in which case the "position angle" returned is as would be
+*      computed for a reference point at (lng0,+90-epsilon) or
+*      (lng0,-90+epsilon), in the limit as epsilon goes to zero.
 *
-*   It is evident that the coordinate system in which the two points are
-*   expressed is irrelevant to the determination of the angular separation
-*   between the points.  However, this is not true of the generalized position
-*   angle.
+*      It is evident that the coordinate system in which the two points are
+*      expressed is irrelevant to the determination of the angular separation
+*      between the points.  However, this is not true of the generalized
+*      position angle.
 *
-*   The generalized position angle is here defined as the angle of
-*   intersection of the great circle containing the reference and field points
-*   with that containing the reference point and the pole.  It has its normal
-*   meaning when the the reference and field points are specified in
-*   equatorial coordinates (right ascension and declination).
+*      The generalized position angle is here defined as the angle of
+*      intersection of the great circle containing the reference and field
+*      points with that containing the reference point and the pole.  It has
+*      its normal meaning when the the reference and field points are
+*      specified in equatorial coordinates (right ascension and declination).
 *
-*   Interchanging the reference and field points changes the position angle in
-*   a non-intuitive way (because the sum of the angles of a spherical triangle
-*   normally exceeds 180 degrees).
+*      Interchanging the reference and field points changes the position angle
+*      in a non-intuitive way (because the sum of the angles of a spherical
+*      triangle normally exceeds 180 degrees).
 *
-*   The position angle is undefined if the reference and field points are
-*   coincident or antipodal.  This may be detected by checking for a distance
-*   of 0 or 180 degrees (within rounding tolerance).  sphdpa() will return an
-*   arbitrary position angle in such circumstances.
+*      The position angle is undefined if the reference and field points are
+*      coincident or antipodal.  This may be detected by checking for a
+*      distance of 0 or 180 degrees (within rounding tolerance).  sphdpa()
+*      will return an arbitrary position angle in such circumstances.
 *
 *
 * sphpad() - Compute field points offset from a given point
@@ -207,11 +205,11 @@
 *                         0: Success.
 *
 * Notes:
-*   sphpad() is implemented analogously to sphdpa() although using sphx2s()
-*   for the inverse transformation.  In particular, when the reference point
-*   is at one of the poles, "position angle" is interpreted as though the
-*   reference point was at (lng0,+90-epsilon) or (lng0,-90+epsilon), in the
-*   limit as epsilon goes to zero.
+*   1: sphpad() is implemented analogously to sphdpa() although using sphx2s()
+*      for the inverse transformation.  In particular, when the reference
+*      point is at one of the poles, "position angle" is interpreted as though
+*      the reference point was at (lng0,+90-epsilon) or (lng0,-90+epsilon), in
+*      the limit as epsilon goes to zero.
 *
 *   Applying sphpad() with the distances and position angles computed by
 *   sphdpa() should return the original field points.
