@@ -1,7 +1,6 @@
 /*============================================================================
-
-  WCSLIB 7.1 - an implementation of the FITS WCS standard.
-  Copyright (C) 1995-2020, Mark Calabretta
+  WCSLIB 7.4 - an implementation of the FITS WCS standard.
+  Copyright (C) 1995-2021, Mark Calabretta
 
   This file is part of WCSLIB.
 
@@ -18,11 +17,9 @@
   You should have received a copy of the GNU Lesser General Public License
   along with WCSLIB.  If not, see http://www.gnu.org/licenses.
 
-  Direct correspondence concerning WCSLIB to mark@calabretta.id.au
-
   Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
   http://www.atnf.csiro.au/people/Mark.Calabretta
-  $Id: HPXcvt.c,v 7.1 2019/12/31 13:25:20 mcalabre Exp $
+  $Id: HPXcvt.c,v 7.4 2021/01/31 02:24:52 mcalabre Exp $
 *=============================================================================
 *
 * HPXcvt reorganises HEALPix data into a 2-D FITS image.  Refer to the usage
@@ -70,20 +67,20 @@ char usage[] =
 #define HEALPIX_NULLVAL (-1.6375e30)
 
 struct healpix {
-  char  *infile;	/* Input file.                                */
-  char  *outfile;	/* Output file.                               */
-  int   col;		/* Input binary table column number.          */
-  char  crdsys;		/* G(alactic), E(cliptic), or (e)Q(uatorial). */
-  char  ordering;	/* R(ing) or N(ested).                        */
-  char  layout;		/* Required output layout,                    */
-                        /*   0: equatorial (default),                 */
-                        /*   1: north, or                             */
-                        /*   2: south.                                */
-  char  quad;		/* Recentre longitude on quadrant (modulo 4). */
-  int   nside;		/* Dimension of a base-resolution pixel.      */
-  int   padding;	/* (Dummy inserted for alignment purposes.)   */
-  long  npix;		/* Total number of pixels in the data array.  */
-  float *data;		/* Pointer to memory allocated to hold data.  */
+  char  *infile;	// Input file.
+  char  *outfile;	// Output file.
+  int   col;		// Input binary table column number.
+  char  crdsys;		// G(alactic), E(cliptic), or (e)Q(uatorial).
+  char  ordering;	// R(ing) or N(ested).
+  char  layout;		// Required output layout,
+                        //   0: equatorial (default),
+                        //   1: north, or
+                        //   2: south.
+  char  quad;		// Recentre longitude on quadrant (modulo 4).
+  int   nside;		// Dimension of a base-resolution pixel.
+  int   padding;	// (Dummy inserted for alignment purposes.)
+  long  npix;		// Total number of pixels in the data array.
+  float *data;		// Pointer to memory allocated to hold data.
 };
 
 int HEALPixIn(struct healpix *hpxdat);
@@ -105,7 +102,7 @@ int main(int argc, char **argv)
   hpxdat.layout   = 0;
   hpxdat.quad     = 0;
 
-  /* Parse options. */
+  // Parse options.
   for (i = 1; i < argc && argv[i][0] == '-'; i++) {
     if (!argv[i][1]) break;
 
@@ -169,14 +166,14 @@ int main(int argc, char **argv)
     hpxdat.infile = "-";
   }
 
-  /* Check accessibility of the input file. */
+  // Check accessibility of the input file.
   if (strcmp(hpxdat.infile, "-") && access(hpxdat.infile, R_OK) == -1) {
     printf("HPXcvt: Cannot access %s.\n", hpxdat.infile);
     return 1;
   }
 
 
-  /* Get the HEALPix data as a vector. */
+  // Get the HEALPix data as a vector.
   if ((status = HEALPixIn(&hpxdat))) {
     return 2;
   }
@@ -189,14 +186,14 @@ int main(int argc, char **argv)
   printf("HPXcvt: Read 12 * %d^2  = %ld pixels with %s indexing.\n",
     hpxdat.nside, hpxdat.npix, (hpxdat.ordering == 'N') ? "nested" : "ring");
 
-  /* Map and write it out as a FITS image. */
+  // Map and write it out as a FITS image.
   if ((status = HPXout(&hpxdat))) return 3;
 
   if (hpxdat.data) free(hpxdat.data);
   return 0;
 }
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
 int HEALPixIn(struct healpix *hpxdat)
 
@@ -211,10 +208,10 @@ int HEALPixIn(struct healpix *hpxdat)
   status = 0;
   hpxdat->data = 0x0;
 
-  /* Open the FITS file and move to the first HDU with NAXIS != 0. */
+  // Open the FITS file and move to the first HDU with NAXIS != 0.
   if (fits_open_data(&fptr, hpxdat->infile, READONLY, &status)) goto fitserr;
 
-  /* Is this the primary HDU or an extension? */
+  // Is this the primary HDU or an extension?
   if (fits_get_hdu_type(fptr, &hdutype, &status)) goto fitserr;
   if (!(hdutype == IMAGE_HDU || hdutype == BINARY_TBL)) {
     fprintf(stderr, "ERROR: %s does not contain HEALPix data.\n",
@@ -223,27 +220,27 @@ int HEALPixIn(struct healpix *hpxdat)
   }
 
 
-  /* Get the image size. */
+  // Get the image size.
   if (fits_read_key_lng(fptr, "NAXIS", &naxis, 0x0, &status)) goto fitserr;
   naxes = malloc(naxis*sizeof(long));
   if (fits_read_keys_lng(fptr, "NAXIS", 1, (int)naxis, naxes, &nfound,
                          &status)) goto fitserr;
 
   if (hdutype == IMAGE_HDU) {
-    /* Look for the first non-degenerate image axis. */
+    // Look for the first non-degenerate image axis.
     for (iaxis = 0; iaxis < nfound; iaxis++) {
       if (naxes[iaxis] > 1) {
-        /* Assume for now that it is the total number of pixels. */
+        // Assume for now that it is the total number of pixels.
         npix = naxes[iaxis];
         break;
       }
     }
 
   } else if (hdutype == BINARY_TBL) {
-    /* Binary tables are simpler. */
+    // Binary tables are simpler.
     if (nfound > 1) nrow = naxes[1];
 
-    /* (Note that fits_get_coltypell() is not available in cfitsio 2.x.) */
+    // (Note that fits_get_coltypell() is not available in cfitsio 2.x.)
     if (fits_get_coltype(fptr, hpxdat->col, 0x0, &repeat, 0x0, &status)) {
       goto fitserr;
     }
@@ -256,15 +253,15 @@ int HEALPixIn(struct healpix *hpxdat)
   }
 
 
-  /* Number of pixels per side of each base-resolution pixel. */
+  // Number of pixels per side of each base-resolution pixel.
   if (fits_read_key_lng(fptr, "NSIDE", &nside, 0x0, &status)) {
-    /* Some HEALPix files, e.g. SFD dust maps, don't record NSIDE. */
+    // Some HEALPix files, e.g. SFD dust maps, don't record NSIDE.
     if (status != KEY_NO_EXIST) goto fitserr;
     status = 0;
   }
 
-  /* FIRSTPIX and LASTPIX, if present, record the 0-relative pixel numbers of
-   * the first and last pixels stored in the data. */
+  // FIRSTPIX and LASTPIX, if present, record the 0-relative pixel numbers of
+  // the first and last pixels stored in the data.
   firstpix = -1;
   if (fits_read_key_lng(fptr, "FIRSTPIX", &firstpix, 0x0, &status)) {
     if (status != KEY_NO_EXIST) goto fitserr;
@@ -278,9 +275,9 @@ int HEALPixIn(struct healpix *hpxdat)
   }
 
   if (!nside) {
-    /* Deduce NSIDE. */
+    // Deduce NSIDE.
     if (lastpix >= 0) {
-      /* If LASTPIX is present without NSIDE we can only assume it's npix. */
+      // If LASTPIX is present without NSIDE we can only assume it's npix.
       nside = (int)(sqrt((double)((lastpix+1) / 12)) + 0.5);
     } else if (hdutype == IMAGE_HDU) {
       nside = (int)(sqrt((double)(npix / 12)) + 0.5);
@@ -292,12 +289,12 @@ int HEALPixIn(struct healpix *hpxdat)
   hpxdat->nside = (int)nside;
   hpxdat->npix  = 12*nside*nside;
 
-  /* Ensure that FIRSTPIX and LASTPIX are set. */
+  // Ensure that FIRSTPIX and LASTPIX are set.
   if (firstpix < 0) firstpix = 0;
   if (lastpix  < 0) lastpix  = hpxdat->npix - 1;
 
 
-  /* Any sign of a coordinate system identifier? */
+  // Any sign of a coordinate system identifier?
   if (fits_read_key_str(fptr, "COORDSYS", crdsys, 0x0, &status)) {
     if (status != KEY_NO_EXIST) goto fitserr;
     status = 0;
@@ -306,13 +303,13 @@ int HEALPixIn(struct healpix *hpxdat)
   } else if (crdsys[0] == 'E') {
     hpxdat->crdsys = 'E';
   } else if (crdsys[0] == 'C') {
-    /* ("celestial") */
+    // ("celestial")
     hpxdat->crdsys = 'Q';
   }
 
-  /* Nested or ring ordering? */
+  // Nested or ring ordering?
   if (fits_read_key_str(fptr, "ORDERING", ordering, 0x0, &status)) {
-    /* Some HEALPix files, e.g. SFD dust maps, don't record ORDERING. */
+    // Some HEALPix files, e.g. SFD dust maps, don't record ORDERING.
     if (status != KEY_NO_EXIST) goto fitserr;
     status = 0;
 
@@ -327,7 +324,7 @@ int HEALPixIn(struct healpix *hpxdat)
   }
 
 
-  /* Allocate memory and read the data. */
+  // Allocate memory and read the data.
   if ((hpxdat->data = malloc((hpxdat->npix)*sizeof(float))) == NULL) {
     perror("HPXcvt");
     goto cleanup;
@@ -357,7 +354,7 @@ int HEALPixIn(struct healpix *hpxdat)
     *(datap++) = nulval;
   }
 
-  /* Clean up. */
+  // Clean up.
   fits_close_file(fptr, &status);
   status = 0;
   return 0;
@@ -371,80 +368,80 @@ cleanup:
   return 1;
 }
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
 int HPXout(struct healpix *hpxdat)
 
 {
-  /* Number of facets on a side of each layout. */
+  // Number of facets on a side of each layout.
   const int NFACET[] = {5, 4, 4};
 
-  /* Arrays that define the facet location and rotation for each recognised
-   * layout.  Bear in mind that these appear to be upside-down, i.e. the top
-   * line contains facet numbers for the bottom row of the output image.
-   * Facets numbered -1 are blank. */
+  // Arrays that define the facet location and rotation for each recognised
+  // layout.  Bear in mind that these appear to be upside-down, i.e. the top
+  // line contains facet numbers for the bottom row of the output image.
+  // Facets numbered -1 are blank.
 
-                              /* Equatorial (diagonal) facet layout. */
+                              // Equatorial (diagonal) facet layout.
   const int FACETS[][5][5] = {{{ 6,  9, -1, -1, -1},
                                { 1,  5,  8, -1, -1},
                                {-1,  0,  4, 11, -1},
                                {-1, -1,  3,  7, 10},
                                {-1, -1, -1,  2,  6}},
-                              /* North polar (X) facet layout. */
+                              // North polar (X) facet layout.
                               {{ 8,  4,  4, 11, -1},
                                { 5,  0,  3,  7, -1},
                                { 5,  1,  2,  7, -1},
                                { 9,  6,  6, 10, -1},
                                {-1, -1, -1, -1, -1}},
-                              /* South polar (X) facet layout. */
+                              // South polar (X) facet layout.
                               {{ 1,  6,  6,  2, -1},
                                { 5,  9, 10,  7, -1},
                                { 5,  8, 11,  7, -1},
                                { 0,  4,  4,  3, -1},
                                {-1, -1, -1, -1, -1}}};
 
-  /* All facets of the equatorial layout are rotated by +45 degrees with
-   * respect to the normal orientation, i.e. that with the equator running
-   * horizontally.  The rotation recorded for the polar facets is the number
-   * of additional positive (anti-clockwise) 90 degree turns with respect to
-   * the equatorial layout. */
+  // All facets of the equatorial layout are rotated by +45 degrees with
+  // respect to the normal orientation, i.e. that with the equator running
+  // horizontally.  The rotation recorded for the polar facets is the number
+  // of additional positive (anti-clockwise) 90 degree turns with respect to
+  // the equatorial layout.
 
-                              /* Equatorial (diagonal), no facet rotation. */
+                              // Equatorial (diagonal), no facet rotation.
   const int FROTAT[][5][5] = {{{ 0,  0,  0,  0,  0},
                                { 0,  0,  0,  0,  0},
                                { 0,  0,  0,  0,  0},
                                { 0,  0,  0,  0,  0},
                                { 0,  0,  0,  0,  0}},
-                              /* North polar (X) facet rotation. */
+                              // North polar (X) facet rotation.
                               {{ 3,  3,  0,  0,  0},
                                { 3,  3,  0,  0,  0},
                                { 2,  2,  1,  1,  0},
                                { 2,  2,  1,  1,  0},
                                { 0,  0,  0,  0,  0}},
-                              /* South polar (X) facet rotation. */
+                              // South polar (X) facet rotation.
                               {{ 1,  1,  2,  2,  0},
                                { 1,  1,  2,  2,  0},
                                { 0,  0,  3,  3,  0},
                                { 0,  0,  3,  3,  0},
                                { 0,  0,  0,  0,  0}}};
 
-  /* Facet halving codes.  0: the facet is whole (or wholly blank),
-   * 1: blanked bottom-right, 2: top-right, 3: top-left, 4: bottom-left.
-   * Positive values mean that the diagonal is included, otherwise not. */
+  // Facet halving codes.  0: the facet is whole (or wholly blank),
+  // 1: blanked bottom-right, 2: top-right, 3: top-left, 4: bottom-left.
+  // Positive values mean that the diagonal is included, otherwise not.
 
-                              /* Equatorial (diagonal), no facet halving. */
+                              // Equatorial (diagonal), no facet halving.
   const int FHALVE[][5][5] = {{{ 0,  0,  0,  0,  0},
                                { 0,  0,  0,  0,  0},
                                { 0,  0,  0,  0,  0},
                                { 0,  0,  0,  0,  0},
                                { 0,  0,  0,  0,  0}},
-                              /* North polar (X) facet halving. */
+                              // North polar (X) facet halving.
                               {{ 0,  1, -4,  0,  0},
                                {-3,  0,  0,  2,  0},
                                { 4,  0,  0, -1,  0},
                                { 0, -2,  3,  0,  0},
                                { 0,  0,  0,  0,  0}},
-                              /* South polar (X) facet halving. */
+                              // South polar (X) facet halving.
                               {{ 0,  1, -4,  0,  0},
                                {-3,  0,  0,  2,  0},
                                { 4,  0,  0, -1,  0},
@@ -464,38 +461,38 @@ int HPXout(struct healpix *hpxdat)
   layout = hpxdat->layout;
   nfacet = NFACET[layout];
 
-  /* Create the output FITS file. */
+  // Create the output FITS file.
   status = 0;
   naxes[0] = nfacet * nside;
   naxes[1] = naxes[0];
   if (fits_create_file(&fptr, hpxdat->outfile, &status)) goto fitserr;
   if (fits_create_img(fptr, FLOAT_IMG, 2, naxes, &status)) goto fitserr;
 
-  /* Write WCS keyrecords. */
+  // Write WCS keyrecords.
   if ((status = HPXhdr(fptr, hpxdat))) goto fitserr;
 
 
-  /* Allocate arrays. */
+  // Allocate arrays.
   if ((healidx = malloc(nside * sizeof(long)))   == NULL ||
       (row     = malloc(nside * sizeof(float)))  == NULL) {
     perror("HPXcvt");
     goto cleanup;
   }
 
-  /* Loop vertically facet-by-facet. */
+  // Loop vertically facet-by-facet.
   fpixel = 1;
   group  = 0;
   nelem  = nside;
   for (jfacet = 0; jfacet < nfacet; jfacet++) {
-    /* Loop row-by-row. */
+    // Loop row-by-row.
     for (j = 0; j < nside; j++) {
-      /* Loop horizontally facet-by-facet. */
+      // Loop horizontally facet-by-facet.
       for (ifacet = 0; ifacet < nfacet; ifacet++) {
         facet = FACETS[layout][jfacet][ifacet];
         rotn  = FROTAT[layout][jfacet][ifacet];
         halve = FHALVE[layout][jfacet][ifacet];
 
-        /* Recentre longitude? */
+        // Recentre longitude?
         if (hpxdat->quad && facet >= 0) {
           if (facet <= 3) {
             facet += hpxdat->quad;
@@ -509,47 +506,47 @@ int HPXout(struct healpix *hpxdat)
           }
         }
 
-        /* Write out the data. */
+        // Write out the data.
         if (facet < 0) {
-          /* A blank facet. */
+          // A blank facet.
           if (fits_write_img_null(fptr, group, fpixel, nelem, &status)) {
             goto fitserr;
           }
 
         } else {
           if (hpxdat->ordering == 'N') {
-            /* Get nested indices. */
+            // Get nested indices.
             status = NESTidx(nside, facet, rotn, j, healidx);
           } else {
-            /* Get ring indices. */
+            // Get ring indices.
             status = RINGidx(nside, facet, rotn, j, healidx);
           }
 
-          /* Gather data into the output vector. */
+          // Gather data into the output vector.
           healp = healidx;
           for (rowp = row; rowp < row + nside; rowp++) {
             *rowp = hpxdat->data[*(healp++)];
           }
 
-          /* Apply blanking to halved facets. */
+          // Apply blanking to halved facets.
           if (halve) {
             if (abs(halve) == 1) {
-              /* Blank bottom-right. */
+              // Blank bottom-right.
               i1 = j;
               i2 = nside;
               if (halve > 0) i1++;
             } else if (abs(halve) == 2) {
-              /* Blank top-right. */
+              // Blank top-right.
               i1 = nside - j;
               i2 = nside;
               if (halve < 0) i1--;
             } else if (abs(halve) == 3) {
-              /* Blank top-left. */
+              // Blank top-left.
               i1 = 0;
               i2 = j;
               if (halve < 0) i2++;
             } else {
-              /* Blank bottom-left. */
+              // Blank bottom-left.
               i1 = 0;
               i2 = nside - j;
               if (halve > 0) i2--;
@@ -560,7 +557,7 @@ int HPXout(struct healpix *hpxdat)
             }
           }
 
-          /* Write out this facet's contribution to this row of the map. */
+          // Write out this facet's contribution to this row of the map.
           if (fits_write_imgnull_flt(fptr, group, fpixel, nelem, row, nulval,
                                      &status)) {
             goto fitserr;
@@ -572,7 +569,7 @@ int HPXout(struct healpix *hpxdat)
     }
   }
 
-  /* Write history. */
+  // Write history.
   sprintf(history, "Original input file: %s", hpxdat->infile);
   fits_write_history(fptr, history, &status);
   sprintf(history, "     Original NSIDE: %d", hpxdat->nside);
@@ -583,7 +580,7 @@ int HPXout(struct healpix *hpxdat)
   fits_write_history(fptr, history, &status);
 
 
-  /* Clean up. */
+  // Clean up.
   fits_close_file(fptr, &status);
   status = 0;
   return 0;
@@ -596,12 +593,12 @@ cleanup:
   return 1;
 }
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
-/* (imap,jmap) are 0-relative pixel coordinates in the output map with origin
- * at the bottom-left corner of the specified facet which is rotated by
- * (45 + rotn * 90) degrees from its natural orientation; imap increases to
- * the right and jmap upwards. */
+// (imap,jmap) are 0-relative pixel coordinates in the output map with origin
+// at the bottom-left corner of the specified facet which is rotated by
+// (45 + rotn * 90) degrees from its natural orientation; imap increases to
+// the right and jmap upwards.
 
 int NESTidx(int nside, int facet, int rotn, int jmap, long *healidx)
 
@@ -609,15 +606,15 @@ int NESTidx(int nside, int facet, int rotn, int jmap, long *healidx)
   int  h, i, imap, j, nside1, bit;
   long *hp;
 
-  /* Nested index (0-relative) of the first pixel in this facet. */
+  // Nested index (0-relative) of the first pixel in this facet.
   h = facet * nside * nside;
 
   nside1 = nside - 1;
   hp = healidx;
   for (imap = 0; imap < nside; imap++, hp++) {
-    /* (i,j) are 0-relative pixel coordinates with origin in the southern
-     * corner of the facet; i increases to the north-east and j to the
-     * north-west. */
+    // (i,j) are 0-relative pixel coordinates with origin in the southern
+    // corner of the facet; i increases to the north-east and j to the
+    // north-west.
     if (rotn == 0) {
       i = nside1 - imap;
       j = jmap;
@@ -649,11 +646,11 @@ int NESTidx(int nside, int facet, int rotn, int jmap, long *healidx)
   return 0;
 }
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
-/* (imap,jmap) pixel coordinates are as described above for NESTidx().  This
- * function computes the double-pixelisation index then converts it to the
- * regular ring index. */
+// (imap,jmap) pixel coordinates are as described above for NESTidx().  This
+// function computes the double-pixelisation index then converts it to the
+// regular ring index.
 
 int RINGidx(int nside, int facet, int rotn, int jmap, long *healidx)
 
@@ -667,19 +664,19 @@ int RINGidx(int nside, int facet, int rotn, int jmap, long *healidx)
   n2side = 2 * nside;
   n8side = 8 * nside;
 
-  /* Double-pixelisation index of the last pixel in the north polar cap. */
+  // Double-pixelisation index of the last pixel in the north polar cap.
   npole = (n2side - 1) * (n2side - 1) - 1;
 
-  /* Double-pixelisation pixel coordinates of the centre of the facet. */
+  // Double-pixelisation pixel coordinates of the centre of the facet.
   i0 = nside * I0[facet];
   j0 = nside * J0[facet];
 
   nside1 = nside - 1;
   hp = healidx;
   for (imap = 0; imap < nside; imap++, hp++) {
-    /* (i,j) are 0-relative, double-pixelisation pixel coordinates.  The
-     * origin is at the intersection of the equator and prime meridian,
-     * i increases to the east (N.B.) and j to the north. */
+    // (i,j) are 0-relative, double-pixelisation pixel coordinates.  The
+    // origin is at the intersection of the equator and prime meridian,
+    // i increases to the east (N.B.) and j to the north.
     if (rotn == 0) {
       i = i0 + nside1 - (jmap + imap);
       j = j0 + jmap - imap;
@@ -694,52 +691,52 @@ int RINGidx(int nside, int facet, int rotn, int jmap, long *healidx)
       j = j0 + jmap + imap - nside1;
     }
 
-    /* Convert i for counting pixels. */
+    // Convert i for counting pixels.
     if (i < 0) i += n8side;
     i++;
 
     if (j > nside) {
-      /* North polar regime. */
+      // North polar regime.
       if (j == n2side) {
         *hp = 0;
       } else {
-        /* Number of pixels in a polar facet with this value of j. */
+        // Number of pixels in a polar facet with this value of j.
         npj = 2 * (n2side - j);
 
-        /* Index of the last pixel in the row above this. */
+        // Index of the last pixel in the row above this.
         *hp = (npj - 1) * (npj - 1) - 1;
 
-        /* Number of pixels in this row in the polar facets before this. */
+        // Number of pixels in this row in the polar facets before this.
         *hp += npj * (i/n2side);
 
-        /* Pixel number in this polar facet. */
+        // Pixel number in this polar facet.
         *hp += i%n2side - (j - nside) - 1;
       }
 
     } else if (j >= -nside) {
-      /* Equatorial regime. */
+      // Equatorial regime.
       *hp = npole + n8side * (nside - j) + i;
 
     } else {
-      /* South polar regime. */
+      // South polar regime.
       *hp = 24 * nside * nside + 1;
 
       if (j > -n2side) {
-        /* Number of pixels in a polar facet with this value of j. */
+        // Number of pixels in a polar facet with this value of j.
         npj = 2 * (j + n2side);
 
-        /* Total number of pixels in this row or below it. */
+        // Total number of pixels in this row or below it.
         *hp -= (npj + 1) * (npj + 1);
 
-        /* Number of pixels in this row in the polar facets before this. */
+        // Number of pixels in this row in the polar facets before this.
         *hp += npj * (i/n2side);
 
-        /* Pixel number in this polar facet. */
+        // Pixel number in this polar facet.
         *hp += i%n2side + (nside + j) - 1;
       }
     }
 
-    /* Convert double-pixelisation index to regular. */
+    // Convert double-pixelisation index to regular.
     *hp -= 1;
     *hp /= 2;
   }
@@ -747,7 +744,7 @@ int RINGidx(int nside, int facet, int rotn, int jmap, long *healidx)
   return 0;
 }
 
-/*--------------------------------------------------------------------------*/
+//----------------------------------------------------------------------------
 
 int HPXhdr(fitsfile *fptr, struct healpix *hpxdat)
 
@@ -763,7 +760,7 @@ int HPXhdr(fitsfile *fptr, struct healpix *hpxdat)
     "No FITS extensions are present", &status);
   fits_write_date(fptr, &status);
 
-  /* Set pixel transformation parameters. */
+  // Set pixel transformation parameters.
   if (hpxdat->layout == 0) {
     crpix1 = (5 * hpxdat->nside + 1) / 2.0f;
   } else {
@@ -796,7 +793,7 @@ int HPXhdr(fitsfile *fptr, struct healpix *hpxdat)
     "[deg] Coordinate increment", &status);
 
 
-  /* Celestial transformation parameters. */
+  // Celestial transformation parameters.
   if (hpxdat->layout == 0) {
     pcode = "HPX";
   } else {
@@ -804,25 +801,25 @@ int HPXhdr(fitsfile *fptr, struct healpix *hpxdat)
   }
 
   if (hpxdat->crdsys == 'G') {
-    /* Galactic. */
+    // Galactic.
     ctype1 = "GLON";
     ctype2 = "GLAT";
     descr1 = "Galactic longitude";
     descr2 = "Galactic  latitude";
   } else if (hpxdat->crdsys == 'E') {
-    /* Ecliptic, who-knows-what. */
+    // Ecliptic, who-knows-what.
     ctype1 = "ELON";
     ctype2 = "ELAT";
     descr1 = "Ecliptic longitude";
     descr2 = "Ecliptic  latitude";
   } else if (hpxdat->crdsys == 'Q') {
-    /* Equatorial, who-knows-what. */
+    // Equatorial, who-knows-what.
     ctype1 = "RA--";
     ctype2 = "DEC-";
     descr1 = "Right ascension";
     descr2 = "Declination";
   } else {
-    /* Unknown. */
+    // Unknown.
     ctype1 = "XLON";
     ctype2 = "XLAT";
     descr1 = "Longitude";
@@ -867,7 +864,7 @@ int HPXhdr(fitsfile *fptr, struct healpix *hpxdat)
       "HPX K parameter  (latitude)", &status);
   }
 
-  /* Commentary. */
+  // Commentary.
   fits_write_record(fptr, " ", &status);
   if (hpxdat->layout == 0) {
     fits_write_comment(fptr,
